pub enum RefactorRequest {
RenameIri {
from_iri: String,
to_iri: String,
},
MergeEntities {
keep_iri: String,
merge_iri: String,
},
ReplaceEntity {
from_iri: String,
to_iri: String,
},
MigrateNamespace {
from_base: String,
to_base: String,
},
MoveEntity {
entity_iri: String,
target_file: PathBuf,
},
ExtractModule {
entity_iris: Vec<String>,
output_file: PathBuf,
leave_stub: bool,
locality: bool,
},
MoveAxioms {
entity_iri: String,
target_file: PathBuf,
statement_indexes: Vec<usize>,
exclude_primary: bool,
},
MergeOntologies {
source_paths: Vec<PathBuf>,
target_file: PathBuf,
},
FlattenImports {
ontology_file: PathBuf,
},
CleanupImports {
ontology_file: PathBuf,
},
}Variants
RenameIri
MergeEntities
ReplaceEntity
MigrateNamespace
MoveEntity
ExtractModule
Fields
MoveAxioms
Move selected Turtle subject statements for an entity to another file.
statement_indexes are 0-based indexes into all_entity_statement_ranges
(excluding the primary type declaration when exclude_primary is true).
MergeOntologies
Merge one or more source ontology Turtle files into a target file.
FlattenImports
Inline imported Turtle axioms into a root ontology and remove owl:imports.
CleanupImports
Remove unused owl:imports lines (heuristic: no imported entities referenced).